# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["AvailabilityStatus"]

AvailabilityStatus: TypeAlias = Literal[
    "InStock", "LimitedAvailability", "PreOrder", "BackOrder", "SoldOut", "OutOfStock", "Discontinued", "Unknown"
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .brands import (
    BrandsResource,
    AsyncBrandsResource,
    BrandsResourceWithRawResponse,
    AsyncBrandsResourceWithRawResponse,
    BrandsResourceWithStreamingResponse,
    AsyncBrandsResourceWithStreamingResponse,
)
from .enrich import (
    EnrichResource,
    AsyncEnrichResource,
    EnrichResourceWithRawResponse,
    AsyncEnrichResourceWithRawResponse,
    EnrichResourceWithStreamingResponse,
    AsyncEnrichResourceWithStreamingResponse,
)
from .search import (
    SearchResource,
    AsyncSearchResource,
    SearchResourceWithRawResponse,
    AsyncSearchResourceWithRawResponse,
    SearchResourceWithStreamingResponse,
    AsyncSearchResourceWithStreamingResponse,
)
from .products import (
    ProductsResource,
    AsyncProductsResource,
    ProductsResourceWithRawResponse,
    AsyncProductsResourceWithRawResponse,
    ProductsResourceWithStreamingResponse,
    AsyncProductsResourceWithStreamingResponse,
)
from .websites import (
    WebsitesResource,
    AsyncWebsitesResource,
    WebsitesResourceWithRawResponse,
    AsyncWebsitesResourceWithRawResponse,
    WebsitesResourceWithStreamingResponse,
    AsyncWebsitesResourceWithStreamingResponse,
)

__all__ = [
    "SearchResource",
    "AsyncSearchResource",
    "SearchResourceWithRawResponse",
    "AsyncSearchResourceWithRawResponse",
    "SearchResourceWithStreamingResponse",
    "AsyncSearchResourceWithStreamingResponse",
    "ProductsResource",
    "AsyncProductsResource",
    "ProductsResourceWithRawResponse",
    "AsyncProductsResourceWithRawResponse",
    "ProductsResourceWithStreamingResponse",
    "AsyncProductsResourceWithStreamingResponse",
    "BrandsResource",
    "AsyncBrandsResource",
    "BrandsResourceWithRawResponse",
    "AsyncBrandsResourceWithRawResponse",
    "BrandsResourceWithStreamingResponse",
    "AsyncBrandsResourceWithStreamingResponse",
    "WebsitesResource",
    "AsyncWebsitesResource",
    "WebsitesResourceWithRawResponse",
    "AsyncWebsitesResourceWithRawResponse",
    "WebsitesResourceWithStreamingResponse",
    "AsyncWebsitesResourceWithStreamingResponse",
    "EnrichResource",
    "AsyncEnrichResource",
    "EnrichResourceWithRawResponse",
    "AsyncEnrichResourceWithRawResponse",
    "EnrichResourceWithStreamingResponse",
    "AsyncEnrichResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .product import Product

__all__ = ["SearchPerformResponse"]

SearchPerformResponse: TypeAlias = List[Product]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .brand import Brand as Brand
from .price import Price as Price
from .product import Product as Product
from .variant import Variant as Variant
from .website import Website as Website
from .redirect_mode import RedirectMode as RedirectMode
from .product_detail import ProductDetail as ProductDetail
from .brand_find_params import BrandFindParams as BrandFindParams
from .availability_status import AvailabilityStatus as AvailabilityStatus
from .search_config_param import SearchConfigParam as SearchConfigParam
from .website_find_params import WebsiteFindParams as WebsiteFindParams
from .search_filters_param import SearchFiltersParam as SearchFiltersParam
from .search_perform_params import SearchPerformParams as SearchPerformParams
from .search_perform_response import SearchPerformResponse as SearchPerformResponse
from .enrich_enrich_url_params import EnrichEnrichURLParams as EnrichEnrichURLParams
from .search_filter_price_param import SearchFilterPriceParam as SearchFilterPriceParam



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .._models import BaseModel

__all__ = ["Variant"]


class Variant(BaseModel):
    image_url: str

    product_id: str

    title: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional

import httpx

from ..types import website_find_params
from .._types import Body, Query, Headers, NotGiven, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.website import Website

__all__ = ["WebsitesResource", "AsyncWebsitesResource"]


class WebsitesResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> WebsitesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/channel3-ai/sdk-python#accessing-raw-response-data-eg-headers
        """
        return WebsitesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> WebsitesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/channel3-ai/sdk-python#with_streaming_response
        """
        return WebsitesResourceWithStreamingResponse(self)

    def find(
        self,
        *,
        query: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[Website]:
        """
        Find a website by URL.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/v0/websites",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"query": query}, website_find_params.WebsiteFindParams),
            ),
            cast_to=Website,
        )


class AsyncWebsitesResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncWebsitesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/channel3-ai/sdk-python#accessing-raw-response-data-eg-headers
        """
        return AsyncWebsitesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncWebsitesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/channel3-ai/sdk-python#with_streaming_response
        """
        return AsyncWebsitesResourceWithStreamingResponse(self)

    async def find(
        self,
        *,
        query: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> Optional[Website]:
        """
        Find a website by URL.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/v0/websites",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform({"query": query}, website_find_params.WebsiteFindParams),
            ),
            cast_to=Website,
        )


class WebsitesResourceWithRawResponse:
    def __init__(self, websites: WebsitesResource) -> None:
        self._websites = websites

        self.find = to_raw_response_wrapper(
            websites.find,
        )


class AsyncWebsitesResourceWithRawResponse:
    def __init__(self, websites: AsyncWebsitesResource) -> None:
        self._websites = websites

        self.find = async_to_raw_response_wrapper(
            websites.find,
        )


class WebsitesResourceWithStreamingResponse:
    def __init__(self, websites: WebsitesResource) -> None:
        self._websites = websites

        self.find = to_streamed_response_wrapper(
            websites.find,
        )


class AsyncWebsitesResourceWithStreamingResponse:
    def __init__(self, websites: AsyncWebsitesResource) -> None:
        self._websites = websites

        self.find = async_to_streamed_response_wrapper(
            websites.find,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import TypedDict

from .search_config_param import SearchConfigParam
from .search_filters_param import SearchFiltersParam

__all__ = ["SearchPerformParams"]


class SearchPerformParams(TypedDict, total=False):
    base64_image: Optional[str]
    """Base64 encoded image"""

    config: SearchConfigParam
    """Optional configuration"""

    context: Optional[str]
    """Optional customer information to personalize search results"""

    filters: SearchFiltersParam
    """Optional filters.

    Search will only consider products that match all of the filters.
    """

    image_url: Optional[str]
    """Image URL"""

    limit: Optional[int]
    """Optional limit on the number of results"""

    query: Optional[str]
    """Search query"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import TypedDict

from .redirect_mode import RedirectMode

__all__ = ["SearchConfigParam"]


class SearchConfigParam(TypedDict, total=False):
    enrich_query: bool
    """
    If True, search will use AI to enrich the query, for example pulling the gender,
    brand, and price range from the query.
    """

    redirect_mode: Optional[RedirectMode]
    """
    "price" redirects to the product page with the lowest price "commission"
    redirects to the product page with the highest commission rate "brand" redirects
    to the brand's product page
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Optional
from typing_extensions import Literal, TypedDict

from .._types import SequenceNotStr
from .availability_status import AvailabilityStatus
from .search_filter_price_param import SearchFilterPriceParam

__all__ = ["SearchFiltersParam"]


class SearchFiltersParam(TypedDict, total=False):
    age: Optional[List[Literal["newborn", "infant", "toddler", "kids", "adult"]]]
    """Filter by age group. Age-agnostic products are treated as adult products."""

    availability: Optional[List[AvailabilityStatus]]
    """If provided, only products with these availability statuses will be returned"""

    brand_ids: Optional[SequenceNotStr[str]]
    """If provided, only products from these brands will be returned"""

    category_ids: Optional[SequenceNotStr[str]]
    """If provided, only products from these categories will be returned"""

    condition: Optional[Literal["new", "refurbished", "used"]]
    """Filter by product condition.

    Incubating: condition data is currently incomplete; products without condition
    data will be included in all condition filter results.
    """

    exclude_product_ids: Optional[SequenceNotStr[str]]
    """If provided, products with these IDs will be excluded from the results"""

    gender: Optional[Literal["male", "female", "unisex"]]

    price: Optional[SearchFilterPriceParam]
    """Price filter. Values are inclusive."""

    website_ids: Optional[SequenceNotStr[str]]
    """If provided, only products from these websites will be returned"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["EnrichEnrichURLParams"]


class EnrichEnrichURLParams(TypedDict, total=False):
    url: Required[str]
    """The URL of the product to enrich"""
